ATNative class
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
adFrom ()
→ String
adLogo ()
→ String
advertiser ()
→ String
appIcon ()
→ String
bdNativeRewardKey ()
→ String
Baidu native act-reward switch for loadNativeAd localExtra.
Put into extraMap, e.g. { ATNativeManager.bdNativeRewardKey(): true }.
checkNativeAdLoadStatus ({required String placementID })
→ Future <Map >
createNativeSubCustomViewAttribute (double width , double height , {double x = 0 , double y = 0 , String backgroundColorStr = '#FFFFFF' , String textColorStr = '#000000' , String textAlignmentStr = 'left' , double textSize = 15 , bool isCustomClick = false , int cornerRadius = 0 , ATCustomViewNative customViewNative = ATCustomViewNative.view , String imagePath = '' , String title = '' })
→ Map
createNativeSubViewAttribute (double width , double height , {double x = 0 , double y = 0 , String backgroundColorStr = '#FFFFFF' , String textColorStr = '#000000' , String textAlignmentStr = 'left' , double textSize = 15 , bool isCustomClick = false , int cornerRadius = 0 })
→ Map
cta ()
→ String
customView ()
→ String
desc ()
→ String
dislike ()
→ String
elementsView ()
→ String
entryNativeScenario ({required String placementID , required String sceneID })
→ Future <bool >
getNativeValidAds ({required String placementID })
→ Future <String >
isAdaptiveHeight ()
→ String
loadNativeAd ({required String placementID , })
→ Future <String >
mainImage ()
→ String
mainTitle ()
→ String
mediaViewFrameKey ()
→ String
nativeAdReady ({required String placementID })
→ Future <bool >
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parent ()
→ String
removeNativeAd ({required String placementID })
→ Future <bool >
showNativeAd ({required String placementID , bool isAdaptiveHeight = false , Map <String , Object ? > ? atCustomContentResult })
→ Future <String >
showSceneNativeAd ({required String placementID , required String sceneID , bool isAdaptiveHeight = false , Map <String , Object ? > ? atCustomContentResult })
→ Future <String >
showSceneNativeAdWithCustomExt ({required String placementID , required String sceneID , required String showCustomExt , bool isAdaptiveHeight = false , Map <String , Object ? > ? atCustomContentResult })
→ Future <String >
starRating ()
→ String
ToponNative ()
→ dynamic
toString ()
→ String
A string representation of this object.
inherited
ttNativeECRewardDurationKey ()
→ String
CSJ (Pangle) native EC reward duration (seconds) for loadNativeAd localExtra.
iOS only (kATTTNativeECRewardDurationKey / ec_reward_duration). Android is a no-op placeholder.
ttNativeECRewardGoldKey ()
→ String
CSJ (Pangle) native EC reward gold for loadNativeAd localExtra.
iOS only (kATTTNativeECRewardGoldKey / ec_reward_gold). Android is a no-op placeholder.