ATSplash class

Constructors

ATSplash()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bottomHeight() → String
bottomRatio() → String
bottomTemplate() → String
checkSplashLoadStatus({required String placementID}) → Future<Map>
entrySplashScenario({required String placementID, required String sceneID}) → Future<bool>
getSplashValidAds({required String placementID}) → Future<String>
loadSplash({required String placementID, required Map extraMap}) → Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showSceneSplash({required String placementID, required String sceneID}) → Future<String>
showSplash({required String placementID}) → Future<String>
showSplashAdWithShowConfig({required String placementID, required String sceneID, required String showCustomExt, Map<String, Object?>? atCustomContentResult}) → Future<String>
splashReady({required String placementID}) → Future<bool>
tolerateTimeout() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited